@@ -6,6 +6,7 @@ from InstrumentDialog import InstrumentDialog
 from BlockDialog import BlockDialog
 from UploadDialog import UploadDialog
 from ProgressionBrowser import ProgressionBrowser
+from InstrumentBrowser import InstrumentBrowser
 from os import path, environ
 from mingus.core import diatonic
 import Options
@@ -48,8 +49,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 
 
 	def fill_combos(self):
-		for x in Options.get_available_instruments():
-			self.ui.instrumentcombo.addItem(x)
 		for x in Options.get_available_movements():
 			self.ui.movement.addItem(x)
 		for x in [1, 2, 4, 8, 16, 32, 64, 128]:
@@ -136,9 +135,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.actionNew,
 			QtCore.SIGNAL("activated()"),
 			self.set_defaults)
-		self.connect(self.ui.instrumentcombo,
-			QtCore.SIGNAL("activated(int)"),
-			lambda x: self.add_instrument())
 		self.connect(self.ui.bpmslide,
 			QtCore.SIGNAL("sliderMoved(int)"),
 			lambda x: self.ui.bpm.setValue(x * 10))
@@ -190,9 +186,6 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			self.highlighted_movement)
 
 		if self.loggedin:
-			self.connect(self.ui.uploadbutton,
-				QtCore.SIGNAL("clicked()"),
-				self.upload_song)
 			self.connect(self.ui.uploadsong,
 				QtCore.SIGNAL("activated()"),
 				self.upload_song)
@@ -207,10 +200,8 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 				self.upload_blocks)
 
 
-			self.ui.uploadbutton.setEnabled(True)
 			self.ui.menuUpload.setEnabled(True)
 		else:
-			self.ui.uploadbutton.setEnabled(False)
 			self.ui.menuUpload.setEnabled(False)
 		
 
@@ -255,7 +246,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			return
 		u = UploadDialog(
 			Options.UPLOAD_INSTRUMENTS,
-			self.get_progressions(),
+			self.get_instruments(),
 			self.credentials)
 		u.setWindowTitle("Upload Instruments") 
 		u.ui.uploadname.setText(self.ui.projectname.text())
@@ -268,7 +259,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 			return
 		u = UploadDialog(
 			Options.UPLOAD_BLOCKS,
-			self.get_progressions(),
+			self.get_blocks(),
 			self.credentials)
 		u.setWindowTitle("Upload Blocks") 
 		u.ui.uploadname.setText(self.ui.projectname.text())
@@ -331,7 +322,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 
 	def add_progression(self):
 		
-		p = ProgressionBrowser(self.ui.progressions, self.filecollection)
+		p = ProgressionBrowser(self.ui.progressions, self.filecollection, Options.UPLOAD_PROGRESSION)
 		p.show()
 		p.exec_()
 		self.progression_changed()
@@ -549,9 +540,9 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		
 
 	def add_instrument(self):
-		self.ui.instruments.addItem(self.ui.instrumentcombo.currentText())
-		self.ui.instruments.setCurrentRow(int(self.ui.instruments.count()) -1)
-		self.edit_instrument()
+		p = InstrumentBrowser(self.ui.instruments, self.filecollection, Options.UPLOAD_INSTRUMENTS)
+		p.show()
+		p.exec_()
 		self.instrument_changed()
 
 	def remove_instrument(self):
